@@ -2,12 +2,12 @@
 
 # called by uscan with '--upstream-version' <version> <file>
 DIR=ehcache-$2.orig
-TAR=../ehcache_$2.orig.tar.gz
+TAR=../ehcache_$2.orig.tar.xz
 
 # clean up the upstream tarball
 svn export http://svn.terracotta.org/svn/ehcache/tags/ehcache-core-$2/ $DIR
 # FIXME: check PDF and DOC files
-GZIP=--best tar czf $TAR -X debian/orig-tar.exclude $DIR
+XZ_OPT=--best tar cJf $TAR -X debian/orig-tar.exclude $DIR
 rm -rf $DIR ../ehcache-core-$2
 
 # move to directory 'tarballs'
